![](https://www.phonexia.com/wp-content/uploads/phonexia-logo-transparent-500px.png)

# Phonexia Transcription Normalization client

This module contains client for communication with [transcription normalization microservice](https://hub.docker.com/repository/docker/phonexia/transcription-normalization/general) developed by [Phonexia](https://phonexia.com).

To use this client you will first need a running instance of any *Phonexia transcription normalization microservice*. If you don't yet have any running instance, don't hesitate to [contact our sales department](mailto:info@phonexia.com).

You can learn more about the transcription normalization technology [here](https://docs.phonexia.com/products/speech-platform-4/technologies/transcription-normalization/).

On [this page](https://docs.phonexia.com/products/speech-platform-4/grpc/api/phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto), you will find a *gRPC API* reference for *transcription normalization microservice*.
